@@ -50,6 +50,8 @@ class MockableTrait:
         int_generator: Callable = lambda: random.randint(0, 100),
         float_generator: Callable = lambda: random.random(),
         string_generator: Callable = lambda: str("sss"),
+        list_len_generator: Callable = lambda: 3,
+        dict_keys_generator: Callable = lambda: ["key1" "key2"],
     ):
         """
         Mocks some serialized data for this port
@@ -67,12 +69,12 @@ class MockableTrait:
         if kind == StreamKind.LIST:
             if not hasattr(self, "child"):
                 raise Exception("Cannot mock a list without a child")
-            return [self.child.mock()]
+            return [self.child.mock() for i in list_len_generator()]
 
         if kind == StreamKind.DICT:
             if not hasattr(self, "child"):
                 raise Exception("Cannot mock a list without a child")
-            return {"hello": self.child.mock(), "world": self.child.mock()}
+            return {key: self.child.mock() for key in dict_keys_generator()}
 
         if kind == StreamKind.STRING:
             return string_generator()
